create or replace package cco_google_maps_k is

 
  -- Author  : LEONARDO LITZ
  -- Created : 07/06/2013 13:18:51
  -- Purpose :
  -- References: https://developers.google.com/maps/documentation
  
/*--Example
  
 declare
result clob;

begin
  -- Call the function
  cco_google_maps_k.recOptions.divHeight := 500;
  cco_google_maps_k.recOptions.divWidth  := 500;  
  cco_google_maps_k.recOptions.Zoom := 'auto';
  
  --Locations
  cco_google_maps_k.recLocations(1).location_address := 'santos, sp';
  cco_google_maps_k.recLocations(1).location_title := 'title santos, sp';  
  cco_google_maps_k.recLocations(1).location_icon := 'http://www.google.com/mapfiles/markerA.png';   
  cco_google_maps_k.recLocations(2).location_address := 'guarulhos, sp';  
  cco_google_maps_k.recLocations(2).location_icon := 'http://www.google.com/mapfiles/markerB.png';   
  cco_google_maps_k.recLocations(3).location_address := 'suzano, sp';    
  cco_google_maps_k.recLocations(4).location_address := 'atibaia, sp';      
  cco_google_maps_k.recLocations(5).location_address := 'osasco, sp';        
  cco_google_maps_k.recLocations(6).location_address := 'alphaville, sp';          
  cco_google_maps_k.recLocations(6).location_icon := 'http://www.google.com/mapfiles/markerP.png';  
  
  --Routes
  cco_google_maps_k.recOptions.DirectionsTravelMode := 'WALKING';
  cco_google_maps_k.recRoutes.location_address_start := 'suzano, sp';
  cco_google_maps_k.recRoutes.location_address_end   := 'sao paulo, sp';  
 
  result := cco_google_maps_k.initialize_f;
  htp.p(result);  


end;
  
*/
 
 --Options Type
 type typ_options is record (divName                          varchar2(40)    default 'map-canvas',
                             divWidth                         number          default 250,
                             divHeight                        number          default 250,
                             divUOMWidth                      varchar2(10)    default 'px',
                             divUOMHeight                     varchar2(10)    default 'px',
                             zoom                             varchar2(10)    default 'auto',
                             backgroundColor                  varchar2(200)   default null, --Color used for the background of the Map div
                             disableDefaultUI                 boolean         default true, --Enables/disables all default UI. May be overridden individually.
                             disableDoubleClickZoom           boolean         default true, --Enables/disables zoom and center on double click. Enabled by default.
                             draggable                        boolean         default true, --If false, prevents the map from being dragged. Dragging is enabled by default.
                             draggableCursor                  varchar2(200)   default null, --The name or url of the cursor to display when mousing over a draggable map.
                             draggingCursor                   varchar2(200)   default null, --The name or url of the cursor to display when the map is being dragged.
                             heading                          number          default null, --The heading for aerial imagery in degrees measured clockwise from cardinal direction North. Headings are snapped to the nearest available angle for which imagery is available.
                             keyboardShortcuts                boolean         default true, --If false, prevents the map from being controlled by the keyboard. Keyboard shortcuts are enabled by default.                              
                             mapMaker                         boolean         default false,--True if Map Maker tiles should be used instead of regular tiles                             
                             mapTypeControl                   boolean         default true, --The initial enabled/disabled state of the Map type control.                              
 
                             maxZoom                          number          default null, --The maximum zoom level which will be displayed on the map. If omitted, or set to null, the maximum zoom from the current map type is used instead.
                             minZoom                          number          default null, --The minimum zoom level which will be displayed on the map. If omitted, or set to null, the minimum zoom from the current map type is used instead.
                             noClear                          boolean         default true, --If true, do not clear the contents of the Map div.
                             overviewMapControl               boolean         default true, --The enabled/disabled state of the Overview Map control.
 
                             panControl                       boolean         default true, --The enabled/disabled state of the Pan control.
                             
                             rotateControl                    boolean         default true, --The enabled/disabled state of the Rotate control.
                             
                             scaleControl                     boolean         default true, --The initial enabled/disabled state of the Scale control.
                             
                             scrollwheel                      boolean         default true, --If false, disables scrollwheel zooming on the map. The scrollwheel is enabled by default.
                             
                             streetViewControl                boolean         default true, --The initial enabled/disabled state of the Street View Pegman control. This control is part of the default UI, and should be set to false when displaying a map type on which the Street View road overlay should not appear (e.g. a non-Earth map type).
                             
                             tilt                             number          default null, --The angle of incidence of the map as measured in degrees from the viewport plane to the map plane. The only currently supported values are 0, indicating no angle of incidence (no tilt), and 45, indicating a tilt of 45deg;. 45deg; imagery is only available for SATELLITE and HYBRID map types, within some locations, and at some zoom levels.  
                             zoomControl                      boolean         default true, --The enabled/disabled state of the Zoom control.
 
                             
                             mapType                           varchar2(40) default 'ROADMAP', --HYBRID This map type displays a transparent layer of major streets on satellite images.
                                                                                               --ROADMAP This map type displays a normal street map.
                                                                                               --SATELLITE This map type displays satellite images.
                                                                                               --TERRAIN This map type displays maps with physical features such as terrain and vegetation.
 
                             DirectionsTravelMode               varchar2(40) default 'DRIVING' --BICYCLING Specifies a bicycling directions request.
                                                                                               --DRIVING Specifies a driving directions request.
                                                                                               --TRANSIT Specifies a transit directions request.
                                                                                               --WALKING Specifies a walking directions request.                                                                                               
 
                            );                                                                     
 
                             
  recOptions  typ_options;                           
 

 --Locations Type
 type typ_locations is record (location_address  varchar2(32767),  --Location Address
                               location_title    varchar2(32767),  --Title of location
                               location_icon     varchar2(32767),  --Icon of location
                               location_content  varchar2(32767)); --Content Detail of location
 
 type typ_tb_locations is table of typ_locations index by pls_integer;                                
 
 recLocations typ_tb_locations;
 

 ---Route Type
 type typ_routes is record (location_address_start        varchar2(32767), --Start Location Address
                            location_address_end          varchar2(32767));--End Location Address
 recRoutes  typ_routes;
 
 
---Initialize
function initialize_f
  return clob;
    

procedure clear_variables_p;    

end cco_google_maps_k;
/
create or replace package body cco_google_maps_k is
 

 
 
 strReturn clob;

procedure alter_session_p
is
begin

  execute immediate('alter session set nls_numeric_characters=''.,''');
    
end alter_session_p;  


  
 
  function initialize_f
    return clob
  is
  pragma autonomous_transaction;
  begin
    
    alter_session_p;
  
strReturn := '
  <head>
    <link href="/maps/documentation/javascript/examples/default.css" rel="stylesheet">
    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false"></script>
<script>
 
var map;  
var directionsDisplay;
var directionsService = new google.maps.DirectionsService();
var geocoder          = new google.maps.Geocoder();
var bounds            = new google.maps.LatLngBounds();
var directionsDisplay = new google.maps.DirectionsRenderer();
 
 
 
function initialize() {
  
  var initial = new google.maps.LatLng(0, 0);
  var mapOptions = {
    center: initial'||chr(10);
    
if(recOptions.zoom is not null)then
strReturn := strReturn||',zoom: '                           ||case when lower(recOptions.zoom) = 'auto' then '0' else recOptions.zoom end||chr(10);
end if;
 
if(recOptions.mapType is not null)then
strReturn := strReturn||',mapTypeId: google.maps.MapTypeId.'||recOptions.mapType||chr(10);
end if;
 
if(recOptions.disableDefaultUI is not null)then
strReturn := strReturn||',disableDefaultUI: '               ||case when recOptions.disableDefaultUI then 'true' else 'false' end||chr(10);
end if;
 
if(recOptions.disableDoubleClickZoom is not null)then
strReturn := strReturn||',disableDoubleClickZoom: '         ||case when recOptions.disableDoubleClickZoom then 'true' else 'false' end||chr(10);
end if;
 
if(recOptions.draggable is not null)then
strReturn := strReturn||',draggable: '                      ||case when recOptions.draggable then 'true' else 'false' end||chr(10);
end if;
 
if(recOptions.draggableCursor is not null)then
strReturn := strReturn||',draggableCursor: '                ||recOptions.draggableCursor||chr(10);
end if;
 
 
if(recOptions.draggingCursor is not null)then
strReturn := strReturn||',draggableCursor: '                ||recOptions.draggingCursor||chr(10);
end if;
 
 
if(recOptions.heading is not null)then
strReturn := strReturn||',heading: '                        ||recOptions.heading||chr(10);
end if;
 
if(recOptions.keyboardShortcuts is not null)then
strReturn := strReturn||',keyboardShortcuts: '              ||case when recOptions.keyboardShortcuts then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.mapMaker is not null)then
strReturn := strReturn||',mapMaker: '                       ||case when recOptions.mapMaker then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.mapTypeControl is not null)then
strReturn := strReturn||',mapTypeControl: '                 ||case when recOptions.mapTypeControl then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.maxZoom is not null)then
strReturn := strReturn||',maxZoom: '                        ||recOptions.maxZoom||chr(10);
end if;
 
 
if(recOptions.minZoom is not null)then
strReturn := strReturn||',minZoom: '                        ||recOptions.minZoom||chr(10);
end if;
 
if(recOptions.noClear is not null)then
strReturn := strReturn||',noClear: '                        ||case when recOptions.noClear then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.overviewMapControl is not null)then
strReturn := strReturn||',overviewMapControl: '             ||case when recOptions.overviewMapControl then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.panControl is not null)then
strReturn := strReturn||',panControl: '                     ||case when recOptions.panControl then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.rotateControl is not null)then
strReturn := strReturn||',rotateControl: '                  ||case when recOptions.rotateControl then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.scaleControl is not null)then
strReturn := strReturn||',scaleControl: '                   ||case when recOptions.scaleControl then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.scrollwheel is not null)then
strReturn := strReturn||',scrollwheel: '                    ||case when recOptions.scrollwheel then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.streetViewControl is not null)then
strReturn := strReturn||',streetViewControl: '              ||case when recOptions.streetViewControl then 'true' else 'false' end||chr(10);
end if;
 
 
if(recOptions.tilt is not null)then
strReturn := strReturn||',tilt: '                              ||recOptions.tilt||chr(10);
end if;
 
if(recOptions.zoomControl is not null)then
strReturn := strReturn||',zoomControl: '                    ||case when recOptions.zoomControl then 'true' else 'false' end||chr(10);
end if;
 
    
strReturn := strReturn||'}
  
 
  map = new google.maps.Map(document.getElementById('''||recOptions.divName||'''), mapOptions);
 
 directionsDisplay.setMap(map);
 
 loadAddress();
 loadRoutes();
 
  }
 
  function codeAddress(address,title,icon,contentString) {
 
  geocoder.geocode( { ''address'': address}, function(results, status) {
  
   if (status == google.maps.GeocoderStatus.OK) {
   bounds.extend(results[0].geometry.location); ';
 
if(lower(recOptions.zoom) = 'auto')then
strReturn := strReturn||'map.fitBounds(bounds); ';
end if;   
 
strReturn := strReturn||'
   var marker = new google.maps.Marker({
   map: map,
   title: title,   
   icon: icon,
   position: results[0].geometry.location
   });
    
    if(contentString != null){
    
      attachSecretMessage(marker, contentString);
    }
    
   } else if (status === google.maps.GeocoderStatus.OVER_QUERY_LIMIT) {    
      
      alert(''The webpage has gone over the requests limit in too short a period of time! '');
      
    } else if (status === google.maps.GeocoderStatus.ZERO_RESULTS) {    
          null;
    } else {
      alert(''Geocode was not successful for the following reason: '' + status);
    }
    
  });
 
}';
 
 
strReturn := strReturn||'
    
function attachSecretMessage(marker, contentString) {
    
  var infowindow = new google.maps.InfoWindow(
      { content: contentString
      });
    
  google.maps.event.addListener(marker, ''click'', function() {
    infowindow.open(map,marker);
  });
 
}
    
function codeRoute(start, end) {
    var request = {
      origin:start,
      destination:end,
      travelMode: google.maps.DirectionsTravelMode.'||recOptions.DirectionsTravelMode||'
  };
  directionsService.route(request, function(response, status) {
    if (status == google.maps.DirectionsStatus.OK) {
      directionsDisplay.setDirections(response);
    }
  });
}';
 
 
---Address
strReturn := strReturn||'
function loadAddress(){
  null;';
  
if(recLocations.count > 0)then
  for dd in 1..recLocations.count loop
   begin
   strReturn := strReturn||'codeAddress('''||recLocations(dd).location_address||''','''||recLocations(dd).location_title||''','''||recLocations(dd).location_icon||''','''||recLocations(dd).location_content||''');';
  exception when no_data_found then
    null;
  end;
 end loop;
end if;
 
strReturn := strReturn||'}';


---Routes 
strReturn := strReturn||'
function loadRoutes(){
  null;';
  
 if(recRoutes.location_address_start is not null
and recRoutes.location_address_end is not null)then
 
   strReturn := strReturn||'codeRoute('''||recRoutes.location_address_start||''','''||recRoutes.location_address_end||''');';
 
end if;
strReturn := strReturn||'}';
 
 
strReturn := strReturn||'
 
google.maps.event.addDomListener(window, ''load'', initialize);
 
</script>
 
  </head>';
strReturn := strReturn||'  <body>';
  
strReturn := strReturn||'<div>';
  
strReturn := strReturn||'<div id="'||recOptions.divName||'" style="width:'||recOptions.divWidth||recOptions.divUOMWidth||';height:'||recOptions.divHeight||recOptions.divUOMHeight||'"></div>';

 
strReturn := strReturn||'<img src="http://static.imasters.com.br/imasters/img/portal/header-logo.png" style="z-index:10001;position:absolute;left:100px;top:150px">';


strReturn := strReturn||'</div>';

strReturn := strReturn||'</body>';
  
return strReturn;
 
  end initialize_f;
 

 
 
procedure clear_variables_p
is
begin
  
   recOptions   := null;
   recRoutes    := null;
   recLocations.delete;   
 
end clear_variables_p;
 


 
 
end cco_google_maps_k;
/
